@@ -19,7 +19,6 @@ bot_statistics = """
 -> Number of extensions loaded: {8}
 """
 
-
 class DebugView(View):
     def __init__(self, ctx: Context):
         super().__init__()
@@ -47,14 +46,14 @@ class DebugView(View):
                 => blacklist user/channel
         """
 
-        from . import BlacklistView
+        from . import Blacklist
 
         embed = EmbedFactory.static_embed(
             self.ctx, "Blacklist/Unblacklist", path="blacklist"
         )
 
         await interaction.response.defer()
-        await self.bot_message.edit(embed=embed, view=BlacklistView(self.ctx))
+        await self.bot_message.edit(embed=embed, view=Blacklist(self.ctx))
 
     @button(label="Change", style=ButtonStyle.green)
     async def change_button(self, button: Button, interaction: MessageInteraction):
@@ -66,23 +65,45 @@ class DebugView(View):
                 => change name
         """
 
-        from . import ChangeView
+        from . import Change
 
         embed = EmbedFactory.static_embed(
             self.ctx, "Change bot information", path="change"
         )
 
         await interaction.response.defer()
-        await self.bot_message.edit(embed=embed, view=ChangeView(self.ctx))
+        await self.bot_message.edit(embed=embed, view=Change(self.ctx))
+
+    @button(label="Cogs", style=ButtonStyle.green)
+    async def cogs_button(self, button: Button, interaction: MessageInteraction):
+        """
+        buttons:
+            -> load 
+                => load cog
+            -> unload 
+                => unload cog
+            -> reload
+                => reload cog/all
+        """
+
+        from . import Cogs
+
+        embed = EmbedFactory.static_embed(
+            self.ctx, "Manage cogs", path="cogs"
+        )
+
+        await interaction.response.defer()
+        await self.bot_message.edit(embed=embed, view=Cogs(self.ctx))
 
     @button(label="Echo", style=ButtonStyle.green)
     async def echo_button(self, button: Button, interaction: MessageInteraction):
         """
         buttons:
-            ->
+            -> send message
+            -> delete message
         """
 
-        from . import ChannelView
+        from . import Channel
 
         embed = EmbedFactory.static_embed(
             self.ctx,
@@ -124,7 +145,7 @@ class DebugView(View):
             return await self.bot_message.edit(embed=embed)
 
         await interaction.send("Loading messages...this might take a while if the channel contains long messages")
-        view = await ChannelView.create(self.ctx, response)
+        view = await Channel.create(self.ctx, response)
         await self.bot_message.edit(view=view)
 
     @button(label="Eval", style=ButtonStyle.green)
@@ -134,30 +155,53 @@ class DebugView(View):
             -> eval
             -> return eval
             -> dir eval
+
                 => output
         """
 
-        from . import EvalView
+        from . import Eval
 
         embed = EmbedFactory.static_embed(
             self.ctx, "Evaluate code", path="eval")
 
         await interaction.response.defer()
-        await self.bot_message.edit(embed=embed, view=EvalView(self.ctx))
+        await self.bot_message.edit(embed=embed, view=Eval(self.ctx))
+
+    @button(label="Github", style=ButtonStyle.green)
+    async def github_button(self, button: Button, interaction: MessageInteraction):
+        """
+        buttons:
+            -> pull
+            -> push
+        """
+
+        from . import Github
+
+        embed = EmbedFactory.static_embed(self.ctx, "Github", path="github")
+
+        await interaction.response.defer()
+        await self.bot_message.edit(embed=embed, view=Github(self.ctx))
 
     @button(label="Invokes", style=ButtonStyle.green)
     async def invoke_button(self, button: Button, interaction: MessageInteraction):
         """
         buttons:
-
+            -> all
+                => all invokes
+            -> find
+                -> ID
+                -> USER
+                -> CHANNEL
+                -> GUILD
+                    => search and return results
         """
 
-        from . import InvokeView
+        from . import Invokes
 
         embed = EmbedFactory.static_embed(self.ctx, "Invokes", path="invokes")
 
         await interaction.response.defer()
-        await self.bot_message.edit(embed=embed, view=InvokeView(self.ctx))
+        await self.bot_message.edit(embed=embed, view=Invokes(self.ctx))
 
     @button(label="Leave guild", style=ButtonStyle.green)
     async def leave_guild_button(self, button: Button, interaction: MessageInteraction):
@@ -167,13 +211,13 @@ class DebugView(View):
                 => leave guild [confirm]
         """
 
-        from . import GuildView
+        from . import Guild
 
         embed = EmbedFactory.static_embed(
             self.ctx, "Leave guild", path="leave_guild")
 
         await interaction.response.defer()
-        await self.bot_message.edit(embed=embed, view=GuildView(self.ctx))
+        await self.bot_message.edit(embed=embed, view=Guild(self.ctx))
 
     @button(label="Go to path", style=ButtonStyle.blurple)
     async def go_to_button(self, button: Button, interaction: MessageInteraction):
@@ -183,30 +227,30 @@ class DebugView(View):
         """
 
         from .dialogs import (
-            BlacklistView,
-            ChangeView,
-            CloseView,
-            EchoView,
-            EvalView,
-            GuildView,
-            InvokeView,
+            Blacklist,
+            Change,
+            Eval,
+            Guild,
+            Invokes,
+            Manage,
+            ViewInfo
         )
 
         paths = {
-            "blacklist": BlacklistView,
-            "change": ChangeView,
-            "close": CloseView,
-            "echo": EchoView,
-            "eval": EvalView,
-            "invokes": InvokeView,
-            "leave_guild": GuildView,
+            "blacklist": Blacklist,
+            "change": Change,
+            "eval": Eval,
+            "invokes": Invokes,
+            "leave_guild": Guild,
+            "manage": Manage,
+            "view": ViewInfo
         }
 
         embed = EmbedFactory.static_embed(
             self.ctx,
             "Go to path",
             path="go_to",
-            description="Type the path you want to go to (eg /blacklist/user)\nNot all paths are available because some require additional info (eg which guild to leave in leave_guild/leave)",
+            description="Type the path you want to go to (eg /blacklist/user)\nNot all paths are available because some require additional info (eg which guild to leave in leave_guild/leave)\n{paths}",
         )
         await self.bot_message.edit(embed=embed)
         await interaction.response.send_message("What path?", ephemeral=True)
@@ -237,6 +281,27 @@ class DebugView(View):
             await self.bot_message.edit(embed=embed)
             await interaction.message.reply("Invalid path, try again")
 
+    @button(label="View", style=ButtonStyle.blurple)
+    async def view_button(self, button: Button, interaction: MessageInteraction):
+        """
+        buttons:
+            -> user
+            -> channel
+            -> guild
+            -> emoji
+            -> any
+
+                => show info
+        """ 
+
+        from . import ViewInfo
+
+        embed = EmbedFactory.static_embed(
+            self.ctx, "View", path="view")
+
+        await interaction.response.defer()
+        await self.bot_message.edit(embed=embed, view=ViewInfo(self.ctx))
+
     @button(label="Stats", style=ButtonStyle.blurple)
     async def stats_button(self, button: Button, interaction: MessageInteraction):
 
@@ -282,16 +347,16 @@ class DebugView(View):
         await interaction.response.defer()
         await self.bot_message.edit(embed=embed)
 
-    @button(label="Close", style=ButtonStyle.danger)
+    @button(label="Manage", style=ButtonStyle.danger)
     async def close_button(self, button: Button, interaction: MessageInteraction):
         """
         buttons:
             => close [confirm]
         """
 
-        from . import CloseView
+        from . import ManageView
 
-        embed = EmbedFactory.static_embed(self.ctx, "Close", path="exit")
+        embed = EmbedFactory.static_embed(self.ctx, "Manage bot", path="manage")
 
         await interaction.response.defer()
-        await self.bot_message.edit(embed=embed, view=CloseView(self.ctx))
+        await self.bot_message.edit(embed=embed, view=ManageView(self.ctx))
