@@ -1,7 +1,10 @@
 from .blacklist import *
 from .change import *
-from .close import *
+from .cogs import *
 from .echo import *
 from .eval import *
+from .github import *
 from .leave_guild import *
 from .invoke import *
+from .manage import *
+from .view import *
