@@ -33,6 +33,12 @@ class BlacklistSnowflake(View):
     def check(self, m: Message):
         return m.author == self.ctx.author and m.channel == self.ctx.channel
 
+    async def interaction_check(self, interaction: MessageInteraction) -> bool:
+        return (
+            interaction.author == self.ctx.author
+            and interaction.channel == self.ctx.channel
+        )
+        
     @button(label="Blacklist", style=ButtonStyle.green)
     async def blacklist_button(self, button: Button, interaction: MessageInteraction):
         cursor = await self.bot._db.cursor()
@@ -74,7 +80,7 @@ class BlacklistSnowflake(View):
                 description=f"Blacklisted {self.snowflake.name} from commands: {content}",
             )
             return await self.bot_message.edit(
-                embed=embed, view=BlacklistView(self.ctx)
+                embed=embed, view=Blacklist(self.ctx)
             )
 
     @button(label="Unblacklist", style=ButtonStyle.green)
@@ -120,14 +126,13 @@ class BlacklistSnowflake(View):
         await self.bot_message.edit(embed=embed)
 
 
-class BlacklistView(View):
+class Blacklist(View):
     def __init__(self, ctx: Context):
         super().__init__()
 
         self.ctx = ctx
         self.bot = ctx.bot
         self.bot_message = get_bot_message(ctx)
-
         self.add_item(MainMenu(ctx))
 
     def check(self, m: Message):
