@@ -5,7 +5,7 @@ from disnake.ui import View, Button, button
 from disnake.ext.commands import Context
 
 
-class ChangeView(View):
+class Change(View):
     def __init__(self, ctx: Context):
         super().__init__()
 
