@@ -7,7 +7,7 @@ from disnake.ui import View, Button, button
 from disnake.ext.commands import Context, Bot
 
 
-class ChannelView(View):
+class Channel(View):
     def __init__(self, ctx: Context, channel: TextChannel):
         super().__init__()
 
@@ -16,7 +16,7 @@ class ChannelView(View):
         self.channel = channel
         self.bot_message = get_bot_message(ctx)
         self.embed = Embed(
-            title=channel.name,
+            title="Viewing: " + channel.name,
             timestamp=self.ctx.message.created_at,
             colour=EMBED_COLOR,
         )
@@ -37,7 +37,7 @@ class ChannelView(View):
 
     @classmethod
     async def create(cls, ctx: Context, channel: TextChannel):
-        self = ChannelView(ctx, channel)
+        self = Channel(ctx, channel)
         await self.load_messages()
         return self
 
