@@ -38,11 +38,16 @@ class FindInvoke(View):
         self.ctx = ctx
         self.bot = ctx.bot
         self.bot_message = get_bot_message(ctx)
-
         self.add_item(MainMenu(ctx))
 
     def check(self, m: Message):
         return m.author == self.ctx.author and m.channel == self.ctx.channel
+        
+    async def interaction_check(self, interaction: MessageInteraction) -> bool:
+        return (
+            interaction.author == self.ctx.author
+            and interaction.channel == self.ctx.channel
+        )
 
     @button(label="ID", style=ButtonStyle.green)
     async def id_button(self, button: Button, interaction: MessageInteraction):
@@ -358,14 +363,13 @@ class FindInvoke(View):
         name = "timestamp"
 
 
-class InvokeView(View):
+class Invokes(View):
     def __init__(self, ctx: Context):
         super().__init__()
 
         self.ctx = ctx
         self.bot = ctx.bot
         self.bot_message = get_bot_message(ctx)
-
         self.add_item(MainMenu(ctx))
 
     async def interaction_check(self, interaction: MessageInteraction) -> bool:
