@@ -141,7 +141,7 @@ class LeaveGuildConfirm(View):
         await self.guild.leave()
 
         try:
-            await self.bot_message.edit(view=GuildView(self.ctx))
+            await self.bot_message.edit(view=Guild(self.ctx))
         except Forbidden:
             pass
 
@@ -153,7 +153,7 @@ class LeaveGuildConfirm(View):
             path="leave_guild/cancel",
             description=f"Didn't leave {self.guild.name}",
         )
-        await self.bot_message.edit(embed=embed, view=GuildView(self.ctx))
+        await self.bot_message.edit(embed=embed, view=Guild(self.ctx))
 
 
 class SelectPZ(Select):
@@ -194,7 +194,7 @@ class SelectAO(Select):
         await self.utils.find_guilds(interaction, clicked)
 
 
-class GuildView(View):
+class Guild(View):
     def __init__(self, ctx: Context):
         super().__init__()
 
