@@ -12,6 +12,8 @@ from disnake import (
     Guild,
     TextChannel,
     User,
+    Emoji,
+    HTTPException,
     utils,
 )
 from disnake.ui import Button
@@ -54,42 +56,10 @@ def clean_code(content: str):
 class FindSnowflake:
     @staticmethod
     async def find_any(bot: Bot, query: str) -> Union[User, Guild, TextChannel, None]:
-        if not query.isalpha():  # id
-            _id = int(query)
-
-            user = bot.get_user(_id)
-            if user:
-                return user
-            user = await bot.fetch_user(_id)
-            if user:
-                return user
-
-            guild = bot.get_guild(_id)
-            if guild:
-                return guild
-            guild = await bot.fetch_guild(_id)
-            if guild:
-                return guild
-
-            channel = bot.get_channel(_id)
-            if isinstance(channel, TextChannel):
-                return channel
-            channel = await bot.fetch_channel(_id)
-            if isinstance(channel, TextChannel):
-                return channel
-
-        # name
-        user = utils.get(bot.users, name=query)
-        if user:
-            return user
-
-        guild = utils.get(bot.guilds, name=query)
-        if guild:
-            return guild
-
-        channel = utils.get(bot.get_all_channels(), name=query)
-        if channel:
-            return channel
+        for method in [FindSnowflake.find_user, FindSnowflake.find_guild, FindSnowflake.find_channel, FindSnowflake.find_emoji]:
+            response = method(query)
+            if response:
+                return response
 
     @staticmethod
     async def find_user(bot: Bot, query: str) -> Optional[User]:
@@ -99,9 +69,12 @@ class FindSnowflake:
             user = bot.get_user(_id)
             if user:
                 return user
-            user = await bot.fetch_user(_id)
-            if user:
-                return user
+            try:
+                user = await bot.fetch_user(_id)
+                return
+            except HTTPException:
+                pass
+
         user = utils.get(bot.users, name=query)
         if user:
             return user
@@ -114,9 +87,11 @@ class FindSnowflake:
             guild = bot.get_guild(_id)
             if guild:
                 return guild
-            guild = await bot.fetch_guild(_id)
-            if guild:
+            try:
+                guild = await bot.fetch_guild(_id)
                 return guild
+            except HTTPException:
+                pass
 
         guild = utils.get(bot.guilds, name=query)
         if guild:
@@ -130,14 +105,27 @@ class FindSnowflake:
             channel = bot.get_channel(_id)
             if isinstance(channel, TextChannel):
                 return channel
-            channel = await bot.fetch_channel(_id)
-            if isinstance(channel, TextChannel):
+            try:
+                channel = await bot.fetch_channel(_id)
                 return channel
+            except HTTPException:
+                pass
 
         channel = utils.get(bot.get_all_channels(), name=query)
         if channel:
             return channel
 
+    @staticmethod
+    async def find_emoji(bot: Bot, query: str) -> Optional[TextChannel]:
+        if not query.isalpha():  # id
+            _id = int(query)
+
+            emoji = bot.get_emoji(_id)
+            if isinstance(emoji, Emoji):
+                return emoji
+
+        emoji = utils.get(bot.emojis, name=query)
+        return emoji
 
 class EmbedFactory:
     """Embed factory"""
@@ -175,6 +163,22 @@ class EmbedFactory:
             colour=EMBED_COLOR,
         ).set_author(name=ctx.author.name, icon_url=ctx.author.avatar.url)
 
+    @staticmethod
+    def error_embed(
+        ctx: Context,
+        reason: str,
+    ) -> Embed:
+        return (
+            Embed(
+                title="Uh oh",
+                description=f"```yaml\n{reason}```",
+                timestamp=ctx.message.created_at,
+                colour=EMBED_COLOR
+            ).set_author(
+                name=ctx.author,
+                icon_url=ctx.author.avatar.url
+            )
+        )
 
 class MainMenu(Button):
     def __init__(self, ctx: Context):
